@@ -383,7 +383,7 @@ public final class CallerCalleesView extends FuncListDisp
 
   @Override
   public List<ExportFormat> getSupportedExportFormats() {
-    List<ExportFormat> formats = new ArrayList<ExportFormat>();
+    List<ExportFormat> formats = new ArrayList<>();
     formats.add(ExportFormat.TEXT);
     //        formats.add(ExportFormat.HTML);
     //        formats.add(ExportFormat.CSV);
@@ -1907,7 +1907,7 @@ public final class CallerCalleesView extends FuncListDisp
 
   @Override
   public List<Subview> getVisibleSubviews() {
-    List<Subview> list = new ArrayList();
+    List<Subview> list = new ArrayList<>();
     list.add(window.getSelectedDetailsSubview());
     list.add(window.getTimelineCallStackSubview());
     list.add(window.getIoCallStackSubview());
@@ -1916,7 +1916,7 @@ public final class CallerCalleesView extends FuncListDisp
 
   @Override
   public List<Subview> getSelectedSubviews() {
-    List<Subview> list = new ArrayList();
+    List<Subview> list = new ArrayList<>();
     list.add(window.getSelectedDetailsSubview());
     return list;
   }
